# Order - API



Este projeto tem como objetivo integrar os pedidos delivery de parceiros ao PDV Teknisa.
A integração funciona de forma autônoma, desde o recebimento do pedido no parceiro até o envio do mesmo a cozinha do restaurante.


## Framework
- [Slim v3](https://www.slimframework.com/docs/v3/) 

## Dependências
### Backend
- Composer - [composer.json](http://gitlab.teknisa.com/odhen/integrations/order-api/-/blob/master/backend/composer.json)

## Arquivos Estruturais
### Backend
#### Arquivos de Configuração
- [env.ini](http://gitlab.teknisa.com/odhen/integrations/order-api/-/blob/master/backend/env.ini) - Responsável pelo apontamento de qual cliente a integração deverá considerar em sua execução
- [configs.json](http://gitlab.teknisa.com/odhen/integrations/order-api/-/blob/master/backend/presets/configs/configs_cloud9.json)
- [config.json](http://gitlab.teknisa.com/odhen/integrations/order-api/-/blob/master/backend/presets/clients/external/cloud9/config.json) - Responsável por definir as credenciais de acesso a API, Apontamento de SMTP e diretório de logs 
- [environment.json](http://gitlab.teknisa.com/odhen/integrations/order-api/-/blob/master/backend/presets/clients/external/cloud9/environment.json) - Reponsável pelas configurações de conexão com o banco de dados (OracleDB)


## Instalação
### Desenvolvimento
1. Com o projeto clonado no seu ambiente Cloud, acesse a pasta ***Backend*** e altere o arquivo [env.ini] com as seguintes informações:
```ini
EXTERNAL_CLIENT_PRESET=cloud9
```

2. Acesse a pasta ***Backend/Configs*** e altere o arquivo [configs.json] com a seguintes informações:
```json
{
    "client"     : "",
    "server"     : "cloud9",
    "logPath"    : "/home/developer/workfolder/logs/orderapi",

    "host"       : "smtp.gmail.com",
    "username"   : "odhensm@gmail.com",
    "from"       : "odhensm@gmail.com",
    "password"   : "OOT0OnaCvj1abDya2aHPqGXs2xA4KK1qdM6Sk0/8T/8D+ihymflpaxgvsfmTpn/dyDYBXyZpb8x/wJthwCVdBw==",
    "SMTPSecure" : "tls",
    "port"       : 587,
    
    "timezone"   : "SP"
}
```
3. Acesse a pasta ***backend/presets/clients/*** copie a pasta [(cloud9)] junto de seus sub-diretórios e cole dentro de ***backend/clients/external***. 

**OBS: Importante manter somente a pasta cloud9 no diretorio "backend/clients/external" afim de evitar que erro no apontamento de cliente gere maiores impactos.***

4. Pelo terminal, acesse a pasta ***backend*** e execute o seguinte comando:
```
composer install
```

## Teste/Validação
#### Ferramentas utilizadas para teste
- [Postman](https://www.postman.com/downloads/)

#### Conferir se a integração esta online
A integração possui um endpoint de boas vindas onde, caso eteja funcionando conforme esperado será retornado a versão e data de última atualização do projeto.


Para teste você deverá configurar seu postaman da seguinte forma:
1. Headers - Deverá ser criado a key ***Authorization*** e seu valor será o será ***"bearer + token de acesso a IDE cloud9"***, seguindo o seguinte formato:

![Print](https://marcossouza1.zeedhi.com/workfolder/images-readme/order-api/headers.png)

- O token pode ser coletado em seu próprio ambiente do cloud9 através do URL, conforme exemplo abaixo:

`https://developer.zeedhi.com/ide.html?token=XXXXXXXXX`

Onde no exemplo acima todo o conteúdo após ***"?token="*** representa os dados que precisamos. Ou seja, no nosso exemplo ***XXXXXXXXX***.

2. Enviar uma Request seguindo o formado abaxo:
- method: GET
- URL: https://developer/workfolder/order-api/backend/service/index.php/

Conforme exemplo abaixo:

![Print](https://marcossouza1.zeedhi.com/workfolder/images-readme/order-api/welcome.png)

Caso tenha seguido corretamente todos os passos anteriores, receberá o seguinte retorno:
```json
{
    "client": "cloud9",
    "version": "X.X.X",
    "revision": "1",
    "date": "dd/mm/yyyy hh:mm",
    "filialCount": 38   
}
```

#### Principais Endpoints
- **[/]** - Retorna informações do projeto
- **[/order]** - Realiza o processamento de Pedido
- **[/orderStatus]** - Retorna o status do pedido, podendo ser: Produzindo, finalizado, expedido etc... 
- **[/orderCancel]** - Cancela pedido
- **[/getConsumerById]** - Retorna credenciais de consumidores (Utilizado para rotina de Credito Pessoal)

#### Json para pedido de TESTE
```json
{
    "saleId": "1527375",
    "orderNumber": "7065",
    "orderType": 1,
    "origin": "CLOUD",
    "date": "2022-03-29 15:29:59",
    "subsidiaryCode": "0005",
    "tax": 5,
    "subTotal": 48.5,
    "troco": 0,
    "latitude": 0,
    "longitude": 0,
    "cpfInNote": null,
    "notes": "",
    "consumerDetail": {
        "clientId": "3",
        "name": "{{$randomFullName}}",
        "email": "{{$randomEmail}}",
        "phone": "",
        "cellPhone": "{{$randomPhoneNumber}}",
        "cpf": "",
        "address": {
            "zipCode": "",
            "street": "Rua Teste",
            "number": "2584",
            "neighborhood": "Centro ",
            "city": "Muriaé",
            "uf": "MG",
            "complement": "APT 201",
            "referencePoint": ""
        }
    },
    "payments": [
        {
            "paymentId": "DIN",
            "value": 19.5
        }
    ],
    "ItemOrder": [
        {
            "title": "04 - Cheese Bacon Burguer",
            "quantity": 1,
            "price": 14.5,
            "total": 14.5,
            "notes": "",
            "ref": "8063101100",
            "ComplementCategories": []
        }
    ],
    "discount": 0,
    "total": 19.5
            }
```




